pub struct PathHashMapping<T> { /* private fields */ }Expand description
A PathHashMapping reads and writes line-oriented “{package_path}={hash}\n” files, e.g.
“data/static_packages”.
Deprecated.
Implementations
Sourceimpl<T> PathHashMapping<T>
impl<T> PathHashMapping<T>
Sourcepub fn deserialize(reader: impl BufRead) -> Result<Self, PathHashMappingError>
pub fn deserialize(reader: impl BufRead) -> Result<Self, PathHashMappingError>
Reads the line-oriented “package-path=hash” static_packages or cache_packages file. Validates the package paths and hashes.
Sourcepub fn contents(&self) -> &SortedVecMap<PackagePath, Hash>
pub fn contents(&self) -> &SortedVecMap<PackagePath, Hash>
Iterator over the contents of the mapping.
Sourcepub fn into_contents(self) -> SortedVecMap<PackagePath, Hash>
pub fn into_contents(self) -> SortedVecMap<PackagePath, Hash>
Iterator over the contents of the mapping, consuming self.
Sourcepub fn hash_for_package(&self, path: &PackagePath) -> Option<Hash>
pub fn hash_for_package(&self, path: &PackagePath) -> Option<Hash>
Get the hash for a package.
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the capacity of the mapping as much as possible.